@@ -241,6 +241,7 @@ test_that("Run examples for one sample", {
                ignore_attr = TRUE)
 
   prtest = hush(print(test4))
+  des = hush(describe(test4))
   p1 = plot(test4)
   p2 = plot(test4,
             type = "c")
@@ -257,6 +258,11 @@ test_that("Run examples for two sample", {
     return(tmp)
   }
 
+  tt1 = t_TOST(extra ~ group,
+               data = sleep,
+               eqb = 2)
+  des = describe(tt1)
+
 
   set.seed(651466441)
 
@@ -561,6 +567,8 @@ test_that("Run examples for two sample", {
                ignore_attr = TRUE)
 
   prtest = hush(print(test4))
+  prtest2 = hush(describe(test4))
+  des = hush(describe(test4))
   p1 = plot(test4)
 
 })
@@ -681,6 +689,12 @@ test_that("Run examples for paired samples", {
                                 sd2 = sd(samp2),
                                 n = length(samp2),
                                 tstat = NULL))
+  test_ragain = extract_r_paired(m1 = mean(samp1),
+                                 sd1 = sd(samp1),
+                                 m2 = mean(samp2),
+                                 #sd2 = sd(samp2),
+                                 n = length(samp2),
+                                 tstat = tsum3$TOST$t[1])
 
   something = extract_r_paired(m1 = mean(samp1),
                                sd1 = sd(samp1),
@@ -885,6 +899,7 @@ test_that("Run examples for paired samples", {
                test4$TOST$p.value[3])
 
   prtest = hush(print(test4))
+  des = hush(describe(test4))
   p1 = plot(test4)
 
 })
